# Dash Charlotte Components

A set of standard Dash components for a fast and modular dashboard building.

- [**Box**](https://github.com/GusFurtado/dash-charlotte/blob/main/dash_charlotte/components/box.py)
- [**Dashboard**](https://github.com/GusFurtado/dash-charlotte/blob/main/dash_charlotte/components/dashboard.py)
- [**Drawer**](https://github.com/GusFurtado/dash-charlotte/blob/main/dash_charlotte/components/drawer.py)
- [**Footer**](https://github.com/GusFurtado/dash-charlotte/blob/main/dash_charlotte/components/footer.py)
- [**Navbar**](https://github.com/GusFurtado/dash-charlotte/blob/main/dash_charlotte/components/navbar.py)
- [**Table**](https://github.com/GusFurtado/dash-charlotte/blob/main/dash_charlotte/components/table.py)